@@ -74,7 +74,7 @@ class HTTPTools():
             return size
         
     @staticmethod
-    def N_m3u8DL_CLI(url, filepath, filename, theadnum=32, exe_path=r'lib\N_m3u8DL-CLI_v3.0.2.exe'):
+    def N_m3u8DL_CLI(url, filepath, filename, theadnum=32, exe_path='N_m3u8DL-CLI_v3.0.2.exe'):
         cmd = exe_path + ' --workDir ' + filepath + ' --saveName ' + filename + ' --maxThreads ' + str(theadnum) + ' --enableDelAfterDone ' + url
         os.popen('chcp 65001')
         os.system(cmd)
