@@ -13,4 +13,4 @@ from tools_hjh.HTTPTools import HTTPTools
 
 from tools_hjh.Log import Log
 
-import tools_hjh.Tools as Tools
+import tools_hjh.Tools
